@@ -45,7 +45,7 @@ def dataflow_from_proto(client: Client, data_service_id: str, proto: api_pb2.Dat
   - proto: Dataflow protobuf object
   Returns: a Dataflow definition
   """
-  component_protos = client.list_dataflow_components(data_service_id, proto.id, deep=True).data
+  component_protos = sorted(client.list_dataflow_components(data_service_id, proto.id, deep=True).data, key=lambda c: c.id)
 
   uuid_map: ComponentUuidToIdMap = {}
   for c in component_protos:
@@ -74,7 +74,7 @@ def dataflow_from_proto(client: Client, data_service_id: str, proto: api_pb2.Dat
                             input_dataflow_id=df.project.id,
                             input_data_feed_id=df.id))
     elif c.type == "group":
-      component_ids = [uuid_map[input.uuid] for input in c.content]
+      component_ids = sorted([uuid_map[input.uuid] for input in c.content])
       groups.append(ComponentGroup(id=c.id, name=c.name, description=c.description, component_ids=component_ids))
 
   return Dataflow(
