@@ -323,7 +323,7 @@ class DataFeed(Definition):
 
     if self.shared_with_all:
       proto.open = True
-      proto.pub_to_roles = ""
+      proto.pubToRoles = ""
     else:
       proto.open = False
       share_roles = []
@@ -334,7 +334,7 @@ class DataFeed(Definition):
           share_roles.append(ds_to_role_map[host_data_service_id])
       except KeyError as e:
         raise KeyError(f"missing role for data service {e}")
-      proto.pub_to_roles = ','.join(share_roles)
+      proto.pubToRoles = ','.join(share_roles)
 
     return proto
 
@@ -348,8 +348,8 @@ class DataFeed(Definition):
       if proto.open:
         df.shared_with_all = True
       else:
-        role_uuids = [r.strip() for r in proto.pub_to_roles.split(",")]
-        df.data_services_shared_with = [role_to_ds_map[uuid] for uuid in role_uuids]
+        role_uuids = [r.strip() for r in proto.pubToRoles.split(",")]
+        df.data_services_shared_with = [role_to_ds_map[uuid] for uuid in role_uuids if uuid in role_to_ds_map]
         if host_data_service not in df.data_services_shared_with:
           df.hidden_from_host_data_service = True
       return df
