@@ -46,7 +46,7 @@ class InlineCode:
       return f'''pathlib.Path(os.path.join(os.path.dirname(os.path.realpath(__file__)), "{self._rel_path}")).read_text()'''
 
 
-def download_dataflow(client: Client, data_service_id: str, dataflow_id: str, hostname: str, resource_base_path: str = "."):
+def download_dataflow(client: Client, data_service_id: str, dataflow_id: str, resource_base_path: str = "."):
   """
   Downloads a Dataflow and writes its definition to a file named `{dataflow_id}.py` under
   `resource_base_path`. Inline code for Transforms and ReadConnectors are written as separate
@@ -58,7 +58,6 @@ def download_dataflow(client: Client, data_service_id: str, dataflow_id: str, ho
   - client: SDK client
   - data_service_id: DataService id
   - dataflow_id: Dataflow id
-  - hostname: Ascend hostname
   - resource_base_path: path to which Dataflow definition and resource files
   are written
   """
@@ -74,7 +73,7 @@ def download_dataflow(client: Client, data_service_id: str, dataflow_id: str, ho
 
   pathlib.Path(dataflow_resource_path).mkdir(parents=True, exist_ok=True)
 
-  rendered_dataflow, inline_code_list = render_dataflow(data_service_id, dataflow, hostname, dataflow_resource_path, resource_base_path)
+  rendered_dataflow, inline_code_list = render_dataflow(data_service_id, dataflow, client.hostname, dataflow_resource_path, resource_base_path)
   for inline_code in inline_code_list:
     with open(inline_code.resource_path, "w") as f:
       f.write(inline_code.code)
@@ -83,7 +82,7 @@ def download_dataflow(client: Client, data_service_id: str, dataflow_id: str, ho
     f.write(rendered_dataflow)
 
 
-def download_data_service(client: Client, data_service_id: str, hostname: str, resource_base_path: str = "."):
+def download_data_service(client: Client, data_service_id: str, resource_base_path: str = "."):
   """
   Downloads a DataService and writes its definition to a file named `{data_service_id}.py`
   under `resource_base_path`. Inline code for Transforms and ReadConnectors are written as separate
@@ -94,7 +93,6 @@ def download_data_service(client: Client, data_service_id: str, hostname: str, r
   Parameters:
   - client: SDK client
   - data_service_id: DataService id
-  - hostname: Ascend hostname
   - resource_base_path: base path to which DataService definition and resource
   files are written
   """
@@ -111,7 +109,7 @@ def download_data_service(client: Client, data_service_id: str, hostname: str, r
   for path in dataflow_resource_paths:
     pathlib.Path(path).mkdir(parents=True, exist_ok=True)
 
-  rendered_data_service, inline_code_list = render_data_service(data_service, hostname, resource_base_path)
+  rendered_data_service, inline_code_list = render_data_service(data_service, client.hostname, resource_base_path)
   for inline_code in inline_code_list:
     with open(inline_code.resource_path, "w") as f:
       f.write(inline_code.code)
